@@ -21,12 +21,12 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-ANTHY_PC= 'anthy'
+ANTHY_PC= 'anthy-unicode'
 PKGDATADIR = '/usr/local/share/ibus-anthy'
 LIBEXECDIR = '/usr/local/libexec'
 LOCALEDIR = '/usr/local/share/locale'
 LAYOUT = 'jp'
 SYMBOL_CHAR = unichr(0x3042)
 ICON_PREFERENCE = 'preferences-desktop'
-VERSION = '1.5.11'
+VERSION = '1.5.14'
 DEBUG = False
