@@ -4,8 +4,8 @@
 # ibus-anthy - The Anthy engine for IBus
 #
 # Copyright (c) 2007-2008 Peng Huang <shawn.p.huang@gmail.com>
-# Copyright (c) 2010-2014 Takao Fujiwara <takao.fujiwara1@gmail.com>
-# Copyright (c) 2007-2014 Red Hat, Inc.
+# Copyright (c) 2010-2019 Takao Fujiwara <takao.fujiwara1@gmail.com>
+# Copyright (c) 2007-2017 Red Hat, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,10 +21,12 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
+ANTHY_PC= 'anthy-unicode'
 PKGDATADIR = '/usr/local/share/ibus-anthy'
 LIBEXECDIR = '/usr/local/libexec'
 LOCALEDIR = '/usr/local/share/locale'
 LAYOUT = 'jp'
 SYMBOL_CHAR = chr(0x3042)
 ICON_PREFERENCE = 'preferences-desktop'
+VERSION = '1.5.14'
 DEBUG = False
